.. _reference_files:

Reference Files
===============

Nancy Grace Roman Space Telescope Reference Files:

.. asdf-autoschemas::
    :standard_prefix: schemas/reference_files

    dark-1.0.0
    distortion-1.0.0
    flat-1.0.0
    gain-1.0.0
    linearity-1.0.0
    mask-1.0.0
    pixelarea-1.0.0
    readnoise-1.0.0
    ref_common-1.0.0
    ref_exposure_type-1.0.0
    ref_optical_element-1.0.0
    saturation-1.0.0
    superbias-1.0.0
    wfi_img_photom-1.0.0
